Module lex

Module lex 

C++ Lexer to preprocess C++ code This lexer is build out of C++20 ISO standard - Chapter 5. Lexical conventions

Structs

Lexer
Lexer to parse C++ source code It’s created from string source code and is used as an Iterator
Token
Token from Lexer parsing Its lifetime is bound to the source code

Enums

LexError
Errors that can occur during lexing
TokenKind